@@ -3,7 +3,7 @@
  interfaces and the corresponding table style sheet, which we define as a
  mapping, and the mapping is unique for each API interface.
 """
-from .models import Mapping
+from .Structs.Mapping import Mapping
 from typing import Dict
 
 
